@@ -365,6 +365,10 @@ static void xpad_pad_constructed (GObject *object)
 
 	xpad_pad_sync_title (pad);
 
+	/* Add CSS style class, so the styling can be overridden by a GTK theme */
+	GtkStyleContext *context = gtk_widget_get_style_context(GTK_WIDGET (pad));
+	gtk_style_context_add_class(context, "XpadPad");
+
 	gtk_widget_show_all (GTK_WIDGET (vbox));
 
 	gtk_widget_hide (pad->priv->toolbar);
@@ -735,7 +739,7 @@ xpad_pad_notify_undo_redo_changed (XpadPad *pad)
 	g_return_if_fail (pad);
 
 	XpadTextBuffer *buffer = NULL;
-	buffer = XPAD_TEXT_BUFFER ((gtk_text_view_get_buffer (GTK_TEXT_VIEW (pad->priv->textview))));
+	buffer = XPAD_TEXT_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (pad->priv->textview)));
 	g_return_if_fail (buffer);
 
 	XpadToolbar *toolbar = NULL;
@@ -790,8 +794,14 @@ xpad_pad_spawn (XpadPad *pad)
 static void
 xpad_pad_clear (XpadPad *pad)
 {
-	GtkSourceBuffer *buffer = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (pad->priv->textview)));
-	gtk_text_buffer_set_text (GTK_TEXT_BUFFER (buffer), "", -1);
+	GtkTextBuffer *buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (pad->priv->textview));
+
+	GtkTextIter start, end;
+	gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
+
+	gtk_text_buffer_begin_user_action (buffer);
+	gtk_text_buffer_delete (buffer, &start, &end);
+	gtk_text_buffer_end_user_action (buffer);
 }
 
 void
@@ -871,6 +881,7 @@ xpad_pad_delete (XpadPad *pad)
 			return;
 
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog), _("_Delete"), GTK_RESPONSE_ACCEPT, _("_Cancel"), GTK_RESPONSE_REJECT, NULL);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
 
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -886,12 +897,20 @@ xpad_pad_delete (XpadPad *pad)
 	if (pad->priv->contentname)
 		fio_remove_file (pad->priv->contentname);
 
+	/* 
+	   This behavior used to be handy for debugging purposes, to create (CTRL+N) and delete (CTRL+DELETE)
+	   pads in a rapid way. However the behavior is unexpected to the user, so it has been disabled by
+	   commenting out the code.
+	*/
+
 	/* Before deleting the current pad, find and set the focus to another pad (if any) */
+	/*
 	GSList *nextPad = g_slist_nth (xpad_pad_group_get_pads(pad->priv->group), 0);
 	if (nextPad->data == pad)
 		nextPad = g_slist_next (nextPad);
 	if (nextPad)
         	xpad_pad_show (nextPad->data);
+	*/
 
 	/* Remove the pad from the group and destroy it. */
 	gtk_widget_destroy (GTK_WIDGET (pad));
@@ -1563,7 +1582,7 @@ menu_get_popup_no_highlight (XpadPad *pad, GtkAccelGroup *accel_group)
 	MENU_ADD (_("_New"), "document-new", GDK_KEY_N, GDK_CONTROL_MASK, xpad_pad_spawn);
 	MENU_ADD (_("_Delete"), "edit-delete", GDK_KEY_Delete, GDK_SHIFT_MASK, xpad_pad_delete);
 	MENU_ADD (_("_Reload"), "reload-pad-content", GDK_KEY_F5, 0, xpad_pad_load_content);
-	MENU_ADD (_("_Close"), "window-close", 0, 0, xpad_pad_close);
+	MENU_ADD (_("_Close"), "window-close", GDK_KEY_W, GDK_CONTROL_MASK, xpad_pad_close);
 
 	/* Edit submenu */
 	item = gtk_menu_item_new_with_mnemonic (_("_Edit"));
